package demo.usage.maps;

import java.util.List;

import com.google.android.maps.*;

import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.graphics.drawable.Drawable;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.os.Bundle;
import android.text.Html;
import android.widget.TextView;

public class MainActivity extends MapActivity {
    
	// Térkép	
	MapView 		myMap;
	MapController 	mc;
	
	// Helymeghatározás
	LocationManager lm;
	AlertDialog 	openGpsSettings;
	
	// Megjelenítés
	TextView 			textInfo;	
	List<Overlay> 		mapOverlays;
	static Drawable 	pointDefaultMarker,
						lineDefaultMarker;						
	MyItemizedOverlay 	pointsOverlay, 
						linesOverlay;
	
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        
        // Térkép elérése
        myMap = (MapView)findViewById(R.id.mymap);
        myMap.setBuiltInZoomControls(true);			// Zoom gombok bekapcsolása                
        
        // Kontroller, és alapbeállítás
        mc = myMap.getController();        
        mc.setCenter(new GeoPoint(47533571, 19033851));
        mc.setZoom(18);
        //mc.scrollBy(120, 120); // Pixelben értendõ
        //mc.animateTo(new GeoPoint(...));
        
        lm = (LocationManager)getSystemService(LOCATION_SERVICE);
        
        // Alapok
        textInfo = (TextView)findViewById(R.id.textInfo);
        if(pointDefaultMarker == null)
        	pointDefaultMarker = getResources().getDrawable(R.drawable.android);
        if(lineDefaultMarker == null)
        	lineDefaultMarker = getResources().getDrawable(R.drawable.point);
        
        // Térkép
        mapOverlays   = myMap.getOverlays();        
        pointsOverlay = new MyItemizedOverlay(pointDefaultMarker);
        linesOverlay  = new MyItemizedOverlay(lineDefaultMarker);
        linesOverlay.setDrawLines(true);	// Rajzoljon vonalat, kösse össze a pontokat        
        mapOverlays.add(linesOverlay);        
        mapOverlays.add(pointsOverlay);
    }
    
    @Override
	protected void onResume() {
		lm.requestLocationUpdates(LocationManager.GPS_PROVIDER, 10*1000, 10, ll);
		super.onResume();
	}

	@Override
	protected void onPause() {
		lm.removeUpdates(ll);
		super.onPause();
	}
	
	
	
	@Override
	protected boolean isRouteDisplayed() { return false; }
    
	// ------------------- GPS adatok feldolgozása --------------------
	private LocationListener ll = new LocationListener() {
		public void onStatusChanged(String provider, int status, Bundle extras) {}
		public void onProviderEnabled(String provider) {
			if(openGpsSettings != null) openGpsSettings.dismiss();
		}
		public void onProviderDisabled(String provider) {
			if(openGpsSettings == null){
				// Összedobunk egy dialógus ablakot, hogy odamenjen-e a beállításokhoz
				AlertDialog.Builder ab = new AlertDialog.Builder(MainActivity.this);
				ab.setTitle("GPS kikapcsolva...").setMessage("Ugrás a GPS beállításokhoz?")
				  .setPositiveButton("Igen", new DialogInterface.OnClickListener() {
						public void onClick(DialogInterface dialog, int which) {							
							startActivity(new Intent(android.provider.Settings.ACTION_LOCATION_SOURCE_SETTINGS));
						}
					}).setNegativeButton("Kihagyom", null);
				openGpsSettings = ab.create();
			}
			openGpsSettings.show();
		}
		
		public void onLocationChanged(Location location) {
			// Aktuális koordináta kiiratása
			textInfo.setText(Html.fromHtml(
							"Latitude:  <b>" + location.getLatitude()  + "</b><br />" +
							"Longitude: <b>" + location.getLongitude() + "</b>"
							));
			
			// Overlay
			GeoPoint p = new GeoPoint(
										(int)(location.getLatitude() * 1E6), 
										(int)(location.getLongitude()* 1E6)
									 );
			OverlayItem item = new OverlayItem(p, null, null);
			//item.setMarker(marker)  // itt lehetőség lenne egyéni képet megadni
			linesOverlay.addOverlay(item);			
			pointsOverlay.justOneOverlay(item);			
			myMap.invalidate();
			mc.animateTo(p);
			//mc.setCenter(p);
		}
	};
    
    
}